'use strict';

var app = require('~/cartridge/scripts/app');
var guard = require('~/cartridge/scripts/guard');

/* API Includes */
var Cart = require('~/cartridge/scripts/models/CartModel');
var PaymentMgr = require('dw/order/PaymentMgr');
var OrderMgr = require('dw/order/OrderMgr');
var Transaction = require('dw/system/Transaction');
var URLUtils = require('dw/web/URLUtils');

var libPayment = require('int_payment_core/cartridge/scripts/lib/libPayment.ds')
var parameterMap = request.httpParameterMap;

/**
 * Authorization to payment through DirectLink for Direct Debits AT, DE and NL
 */
function Authorize(args) {
	var orderNo = args.OrderNo;
    var paymentInstrument = args.PaymentInstrument;

    var order = OrderMgr.getOrder(args.OrderNo);
    var res = libPayment.SendDirectDebitsAuthorization(session.forms.billing.paymentMethods, order, request.locale);
	
    if(res.success) {
        Transaction.wrap(function () {
        	PaymentInstrument.paymentTransaction.transactionID = res.PayID;
        	PaymentInstrument.paymentTransaction.paymentProcessor = PaymentMgr.getPaymentMethod(res.PaymentMethodIDOut).getPaymentProcessor();
        	PaymentInstrument.paymentTransaction.custom.paymentStatus = res.Status;
        	PaymentInstrument.custom.paymentMethod = res.PaymentMethod;
        	PaymentInstrument.creditCardType = res.Brand;
        	PaymentInstrument.paymentTransaction.custom.paymentStatusDescription = res.StatusDescription;
        });
        return {authorized: true};
    } else {
    	if(res.ResultStatusCheck == "RETRY") {
    		return {authorized: true};
    	} else {
    		return {error: true};
    	}
    }
}

/**
 * Verifies Direct Debits DE, NL and AT data forms, the required fields to be completed, the data length for some fields and expiration date to be valid, set in future. If the verification was successful a direct debit payment instrument is created.
 */
function Handle(args) {
	var res,paymentInstrument;
	Transaction.wrap(function () {
		res = libPayment.VerifyPaymentDirectDebits(session.forms.billing.paymentMethods, customer);
	});
	if(res.success) {
		if(args.Basket == null || session.forms.billing.paymentMethods.selectedPaymentMethodID.value == null){
			return {error: true};
		}

		var cart = app.getModel('Cart').get(args.Basket);
		var paymentType = session.forms.billing.paymentMethods.selectedPaymentMethodID.value;
		
	    Transaction.wrap(function () {
	        cart.removeExistingPaymentInstruments(paymentType);
	        paymentInstrument = cart.createPaymentInstrument(paymentType, cart.getNonGiftCertificateAmount());
	    });
	    
	    if(paymentType == 'DIRECT_DEBITS_DE') {
			Transaction.wrap(function () {
				paymentInstrument.creditCardHolder = res.DirectDebitsForm.cn.htmlValue;
				paymentInstrument.creditCardExpirationMonth = res.DirectDebitsForm.month.selectedOption.value;
				paymentInstrument.creditCardExpirationYear = res.DirectDebitsForm.year.selectedOption.value;
			});
			return {success: true};
	    } else if(paymentType == 'DIRECT_DEBITS_NL') {
	    	return {success: true};
	    } else if(paymentType == 'DIRECT_DEBITS_AT') {
		    Transaction.wrap(function () {
				paymentInstrument.creditCardHolder = res.DirectDebitsForm.cn.htmlValue;
				paymentInstrument.creditCardExpirationMonth = res.DirectDebitsForm.month.selectedOption.value;
				paymentInstrument.creditCardExpirationYear = res.DirectDebitsForm.year.selectedOption.value;
		    });
	    	return {success: true};
	    } else {
	    	return {error: true};
	    }
	} else {
		libPayment.InvalidatePaymentDirectDebitsFormElements(res.DirectDebitsStatus, res.DirectDebitsForm);
		return {error: true};
	}
}

exports.Authorize = Authorize;
exports.Handle = Handle;

